@@ -8,7 +8,9 @@ import (
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/config"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/kube"
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/util"
+
 	"k8s.io/klog"
+	utilnet "k8s.io/utils/net"
 )
 
 func (n *OvnNode) createManagementPort(hostSubnets []*net.IPNet, nodeAnnotator kube.Annotator,
@@ -30,7 +32,7 @@ func (n *OvnNode) createManagementPort(hostSubnets []*net.IPNet, nodeAnnotator k
 		"--", "--may-exist", "add-port", "br-int", util.K8sMgmtIntfName,
 		"--", "set", "interface", util.K8sMgmtIntfName,
 		"type=internal", "mtu_request="+fmt.Sprintf("%d", config.Default.MTU),
-		"external-ids:iface-id=k8s-"+nodeName)
+		"external-ids:iface-id="+util.K8sPrefix+nodeName)
 	if err != nil {
 		klog.Errorf("Failed to add port to br-int, stdout: %q, stderr: %q, error: %v", stdout, stderr, err)
 		return err
@@ -44,12 +46,12 @@ func (n *OvnNode) createManagementPort(hostSubnets []*net.IPNet, nodeAnnotator k
 	_, stderr, err = util.RunOVSVsctl("set", "interface", util.K8sMgmtIntfName,
 		fmt.Sprintf("mac=%s", strings.ReplaceAll(macAddress.String(), ":", "\\:")))
 	if err != nil {
-		klog.Errorf("failed to persist MAC address %q for %q: stderr:%s (%v)", macAddress.String(),
+		klog.Errorf("Failed to persist MAC address %q for %q: stderr:%s (%v)", macAddress.String(),
 			util.K8sMgmtIntfName, stderr, err)
 		return err
 	}
 
-	err = createPlatformManagementPort(util.K8sMgmtIntfName, hostSubnets, n.stopChan)
+	cfg, err := createPlatformManagementPort(util.K8sMgmtIntfName, hostSubnets, n.stopChan)
 	if err != nil {
 		return err
 	}
@@ -58,6 +60,41 @@ func (n *OvnNode) createManagementPort(hostSubnets []*net.IPNet, nodeAnnotator k
 		return err
 	}
 
+	if config.Gateway.Mode == config.GatewayModeLocal {
+		var gatewayIfAddrs []*net.IPNet
+		for _, hostSubnet := range hostSubnets {
+			// local gateway mode uses mp0 as default path for all ingress traffic into OVN
+			var nextHop *net.IPNet
+			if utilnet.IsIPv6CIDR(hostSubnet) {
+				nextHop = cfg.ipv6.ifAddr
+			} else {
+				nextHop = cfg.ipv4.ifAddr
+			}
+			gatewayIfAddrs = append(gatewayIfAddrs, nextHop)
+
+			// add iptables masquerading for mp0 to exit the host for egress
+			cidr := nextHop.IP.Mask(nextHop.Mask)
+			cidrNet := &net.IPNet{IP: cidr, Mask: nextHop.Mask}
+			err = initLocalGatewayNATRules(util.K8sMgmtIntfName, cidrNet)
+			if err != nil {
+				return fmt.Errorf("failed to add local NAT rules for: %s, err: %v", util.K8sMgmtIntfName, err)
+			}
+		}
+
+		if config.Gateway.NodeportEnable {
+			localAddrSet, err := getLocalAddrs()
+			if err != nil {
+				return err
+			}
+			err = n.watchLocalPorts(
+				newLocalPortWatcherData(gatewayIfAddrs, n.recorder, localAddrSet),
+			)
+			if err != nil {
+				return err
+			}
+		}
+	}
+
 	waiter.AddWait(managementPortReady, nil)
 	return nil
 }
